@@ -1,3 +1,6 @@
+#![cfg_attr(feature = "external_doc", feature(external_doc))]
+#![cfg_attr(feature = "external_doc", doc(include = "../README.md"))]
+
 extern crate proc_macro;
 extern crate proc_macro2;
 
